@@ -1,3 +1,4 @@
+# *_*coding:utf-8 *_*
 import getpass
 import sys
 import typing
@@ -9,7 +10,7 @@ import pymysql
 
 from sqlstar.core import DatabaseURL
 from sqlstar.interfaces import ConnectionBackend, DatabaseBackend
-from sqlstar.utils import check_dtype
+from sqlstar.utils import check_dtype_mysql
 
 warnings.filterwarnings('ignore')
 warnings.simplefilter('ignore')
@@ -160,20 +161,19 @@ class MySQLConnection(ConnectionBackend):
         :param cols: columns
         :return:
         """
-        # Convert list data into SQL insert syntax format: (.),(.)... ,(.)
-        format_data = ", ".join(str(tuple(row)) for row in data)
+        assert self._connection is not None, "Connection is not acquired"
+        cursor = self._connection.cursor()
+        INSERT_MANY = "INSERT IGNORE INTO {table}  ({cols})  VALUES ({values});".format(
+            table=table,
+            cols=", ".join(["`%s`" % col for col in cols]),
+            values=", ".join(["%s" for col in cols]))
 
-        INSERT_MANY_DATA = """
-                    INSERT IGNORE INTO {}  ({})  VALUES {};
-                    """.format(table,
-                               ", ".join(["`%s`" % col for col in cols]),
-                               format_data)
-
-        self.execute(INSERT_MANY_DATA)
+        cursor.executemany(INSERT_MANY, data)
         Console().print(f"[bold cyan]{table}[/bold cyan] inserts [bold cyan]"
                         f"{len(data)}[/bold cyan] records ✨ 🍰 ✨")
+        cursor.close()
 
-    def insert_df(self, table, df: pd.DataFrame):
+    def insert_df(self, table, df: pd.DataFrame, dropna=True, **kwargs):
         """Insert Dataframe type of data
 
         # transform dtype
@@ -181,6 +181,7 @@ class MySQLConnection(ConnectionBackend):
 
         :param table:
         :param df: Dataframe
+        :param dropna: bool
 
         :return:
         """
@@ -188,16 +189,14 @@ class MySQLConnection(ConnectionBackend):
             Console().print('There seems to be no data 😅', style='red')
         else:
             cols = df.columns.tolist()
-            for col in cols:
-                df.loc[:, col] = df.loc[:, col].astype(str)
-            try:
-                if len(cols) > 1:
-                    data = [tuple(row) for row in df[cols].values]
-                else:
-                    data = ['("' + row[0] + '")' for row in df[cols].values]
-            except Exception as error:
-                raise Exception(
-                    'Maybe you should process null values first...')
+
+            if dropna:
+                df.dropna(axis=kwargs.get('axis', 0),
+                          how=kwargs.get('how', 'any'),
+                          thresh=kwargs.get('thresh'),
+                          subset=kwargs.get('subset'),
+                          inplace=True)
+            data = [tuple(row) for row in df[cols].values]
             self.insert_many(table, data, cols)
 
     def truncate_table(self, table):
@@ -227,7 +226,7 @@ class MySQLConnection(ConnectionBackend):
     def drop_table(self, table):
         """Drop table"""
         DROP_TABLE = f"""DROP TABLE IF EXISTS `{table}`;"""
-        data = self.fetch_all(f'''SELECT * FROM {table} LIMIT 10''')
+        data = self.fetch_all(f'''SELECT * FROM {table} LIMIT 10;''')
 
         # if the table is not empty, warning user
         if data:
@@ -271,7 +270,7 @@ class MySQLConnection(ConnectionBackend):
             if dtype:
                 COLUMNS.append(f'''`{col}` {dtype} COMMENT "{comment}"''')
             else:
-                infer_dtype = check_dtype(df[col].dtypes)
+                infer_dtype = check_dtype_mysql(df[col].dtypes)
                 COLUMNS.append(
                     f'''`{col}` {infer_dtype} COMMENT "{comment}"''')
 
